@@ -50,7 +50,6 @@ from .test_pyfftw_base import run_test_suites
 from .test_pyfftw_numpy_interface import complex_dtypes, real_dtypes
 from ._get_default_args import get_default_args
 
-from distutils.version import LooseVersion
 import unittest
 import numpy
 
@@ -65,8 +64,13 @@ else:
 
 import warnings
 import copy
+
+from packaging.version import Version
+
+
 warnings.filterwarnings('always')
 
+
 def make_complex_data(shape, dtype):
     ar, ai = dtype(numpy.random.randn(2, *shape))
     ac = ar + 1j*ai
@@ -462,7 +466,10 @@ class InterfacesDaskFFTTestFFT(unittest.TestCase):
                 self.validate(dtype_tuple[1],
                         test_shape, dtype, s, kwargs)
 
-
+    @unittest.skipIf(
+        Version(numpy.version.version) >= Version("2.0"),
+        reason="Unsupported for Numpy >=2.0"
+    )
     def test_dtype_coercion(self):
         # Make sure we input a dtype that needs to be coerced
         if functions[self.func] == 'r2c':
@@ -493,7 +500,7 @@ class InterfacesDaskFFTTestFFT(unittest.TestCase):
                         input_array, s, **kwargs)
 
                 self.assertTrue(
-                        numpy.alltrue(input_array == orig_input_array))
+                        numpy.all(input_array == orig_input_array))
 
 
 class InterfacesDaskFFTTestFFT2(InterfacesDaskFFTTestFFT):
